=============
linchackathon
=============


.. image:: https://img.shields.io/pypi/v/linchackathon.svg
        :target: https://pypi.python.org/pypi/linchackathon

.. image:: https://img.shields.io/travis/YasserMahfoud/linchackathon.svg
        :target: https://travis-ci.com/YasserMahfoud/linchackathon

.. image:: https://readthedocs.org/projects/linchackathon/badge/?version=latest
        :target: https://linchackathon.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




A package needed to participate in LINC's Hackathon


* Free software: MIT license
* Documentation: https://linchackathon.readthedocs.io.

